@@ -1,4 +1,5 @@
 import asyncio
+import copy
 import json
 from datetime import date, timedelta
 from typing import Dict, Tuple
@@ -12,6 +13,7 @@ from liualgotrader.common.data_loader import DataLoader  # type: ignore
 from liualgotrader.common.database import fetch_as_dataframe
 from liualgotrader.common.tlog import tlog
 from liualgotrader.models.accounts import Accounts
+from liualgotrader.models.optimizer import OptimizerRun
 from liualgotrader.models.portfolio import Portfolio
 from liualgotrader.trading.trader_factory import trader_factory
 
@@ -298,72 +300,36 @@ def trades_analysis(trades: pd.DataFrame, batch_id: str) -> pd.DataFrame:
 def symobl_trade_analytics(
     symbol_df: pd.DataFrame, open_price: float, plt
 ) -> Tuple[pd.DataFrame, float]:
-    delta = 0.0
-    profit = 0.0
 
-    operations = []
-    deltas = []
-    profits = []
-    times = []
-    prices = []
-    qtys = []
-    indicators = []
-    target_price = []
-    stop_price = []
-    daily_change = []
-    precent_vwap = []
-    algo_names = []
+    d = copy.deepcopy(symbol_df).drop(
+        columns=[
+            "trade_id",
+            "algo_run_id",
+            "symbol",
+            "tstamp",
+            "expire_tstamp",
+            "batch_id",
+            "start_time",
+        ]
+    )
+
+    d["trade"] = symbol_df.apply(
+        lambda row: row.price
+        * row.qty
+        * (1 if row.operation == "sell" and row.qty > 0 else -1),
+        axis=1,
+    )
+    d["balance"] = d.trade.cumsum()
+
     for _, row in symbol_df.iterrows():
-        delta = (
-            row["price"]
-            * row["qty"]
-            * (1 if row["operation"] == "sell" and row["qty"] > 0 else -1)
-        )
-        profit += float(delta)
         plt.scatter(
-            row["client_time"].to_pydatetime(),
+            row["client_time"],
             row["price"],
             c="g" if row["operation"] == "buy" else "r",
             s=100,
         )
-        algo_names.append(row["algo_name"])
-        deltas.append(round(delta, 2))
-        profits.append(round(profit, 2))
-        operations.append(row["operation"])
-        times.append(pd.to_datetime(row["client_time"]))
-        prices.append(row["price"])
-        qtys.append(row["qty"])
-        indicator = json.loads(row.indicators)
-        indicators.append(indicator)
-        target_price.append(row["target_price"])
-        stop_price.append(row["stop_price"])
-        daily_change.append(
-            f"{round(100.0 * (float(row['price']) - open_price) / open_price, 2)}%"
-        )
-        precent_vwap.append(
-            f"{round(100.0 * (indicator['buy']['avg'] - open_price) / open_price, 2)}%"
-            if "buy" in indicator
-            and indicator["buy"]
-            and "avg" in indicator["buy"]
-            else ""
-        )
 
-    d = {
-        "balance": profits,
-        "trade": deltas,
-        "algo": algo_names,
-        "operation": operations,
-        "at": times,
-        "price": prices,
-        "qty": qtys,
-        "daily change": daily_change,
-        "vwap": precent_vwap,
-        "indicators": indicators,
-        "target price": target_price,
-        "stop price": stop_price,
-    }
-
-    return pd.DataFrame(d), profit
+    return d, d.trade.sum()
 
 
 def calc_symbol_trades_returns(
@@ -431,7 +397,7 @@ def calc_batch_returns(batch_id: str) -> pd.DataFrame:
 
     td = trader.get_trading_days(start_date=start_date, end_date=end_date)
 
-    td["agg_value"] = 0.0
+    td["equity"] = 0.0
     td["cash"] = portfolio.portfolio_size
 
     num_symbols = len(trades.symbol.unique().tolist())
@@ -442,10 +408,10 @@ def calc_batch_returns(batch_id: str) -> pd.DataFrame:
         )
         calc_symbol_trades_returns(symbol, symbol_trades, td, data_loader)
 
-    td["totals"] = td["agg_value"] + td["cash"]
+    td["totals"] = td["equity"] + td["cash"]
     # td["date"] = pd.to_datetime(td.index)
     # td = td.set_index("date")
-    return pd.DataFrame(td, columns=["agg_value", "cash", "totals"])
+    return pd.DataFrame(td, columns=["equity", "cash", "totals"])
 
 
 def compare_to_symbol_returns(portfolio_id: str, symbol: str) -> pd.DataFrame:
@@ -471,7 +437,7 @@ def get_cash(account_id: int, initial_cash: float) -> pd.DataFrame:
     df = loop.run_until_complete(Accounts.get_transactions(account_id))
     df = df.groupby(df.index.date).sum()
     df.iloc[0].amount += initial_cash
-    r = pd.date_range(start=df.index.min(), end=df.index.max())
+    r = pd.date_range(start=df.index.min(), end=df.index.max(), name="date")
     df.reindex(r).fillna(method="ffill")
     df["cash"] = df.amount.cumsum()
     df.index.rename("date", inplace=True)
@@ -482,9 +448,14 @@ def calc_portfolio_returns(portfolio_id: str) -> pd.DataFrame:
     loop = asyncio.get_event_loop()
     _ = loop.run_until_complete(Portfolio.load_by_portfolio_id(portfolio_id))
 
-    account_id, initial_account_size = loop.run_until_complete(
-        Portfolio.load_details(portfolio_id)
-    )
+    try:
+        account_id, initial_account_size = loop.run_until_complete(
+            Portfolio.load_details(portfolio_id)
+        )
+    except Exception:
+        print("ERROR loading portfolio-id, please verify id and re-run.")
+        return pd.DataFrame()
+
     data_loader = DataLoader()
     trades = load_trades_by_portfolio(portfolio_id)
     start_date = trades.client_time.min().date()
@@ -497,7 +468,9 @@ def calc_portfolio_returns(portfolio_id: str) -> pd.DataFrame:
 
     cash_df = get_cash(account_id, initial_account_size)
     symbols = trades.symbol.unique().tolist()
-    for i in tqdm(range(len(symbols))):
+    for i in tqdm(
+        range(len(symbols)), desc=f"loading portfolio {portfolio_id}"
+    ):
         symbol = symbols[i]
         symbol_trades = trades[trades.symbol == symbol].sort_values(
             by="client_time"
@@ -507,3 +480,23 @@ def calc_portfolio_returns(portfolio_id: str) -> pd.DataFrame:
     td = td.fillna(method="ffill")
     td["totals"] = td["equity"] + td["cash"]
     return pd.DataFrame(td, columns=["equity", "cash", "totals"])
+
+
+def calc_hyperparameters_analysis(optimizer_run_id: str) -> pd.DataFrame:
+    loop = asyncio.get_event_loop()
+
+    portfolio_ids_parameters = loop.run_until_complete(
+        OptimizerRun.get_portfolio_ids_parameters(optimizer_run_id)
+    )
+    portfolio_ids, hypers = list(map(list, zip(*portfolio_ids_parameters)))
+    df = None
+    if len(portfolio_ids):
+        for i in tqdm(range(len(portfolio_ids)), desc="Loading Portfolios"):
+            _df = calc_portfolio_returns(portfolio_ids[i])
+            _df["portfolio_id"] = portfolio_ids[i]
+            _df["configurations"] = hypers[i]
+            _df.reset_index(inplace=True)
+            _df = _df.set_index(["portfolio_id", "date"])
+            df = pd.concat([df, _df], axis=0) if df is not None else _df
+
+    return df
