@@ -346,15 +346,15 @@ async def update_partially_filled_order(
 
 
 async def update_filled_order(strategy: Strategy, order: Order) -> None:
-    qty = int(order.filled_qty)
+    qty = float(order.filled_qty)
     new_qty = qty - abs(trading_data.partial_fills.get(order.symbol, 0))
     if order.side == "sell":
-        qty *= -1
+        qty *= -1.0
 
     tlog(f"update_filled_order new qty {new_qty} for {order}")
     trading_data.positions[order.symbol] = trading_data.positions.get(
-        order.symbol, 0
-    ) - trading_data.partial_fills.get(order.symbol, 0)
+        order.symbol, 0.0
+    ) - trading_data.partial_fills.get(order.symbol, 0.0)
     trading_data.partial_fills[order.symbol] = 0
     trading_data.positions[order.symbol] += qty
 
@@ -743,12 +743,11 @@ async def do_strategies(
                 symbol=symbol,
                 what=what,
             )
-        else:
-            if what.get("reject", False):
-                if s.name not in rejects:
-                    rejects[s.name] = [symbol]
-                else:
-                    rejects[s.name].append(symbol)
+        elif what.get("reject", False):
+            if s.name not in rejects:
+                rejects[s.name] = [symbol]
+            else:
+                rejects[s.name].append(symbol)
 
 
 async def handle_aggregate(
@@ -849,13 +848,12 @@ async def queue_consumer(
                 if data["EV"] == "trade_update":
                     tlog(f"received trade_update: {data}")
                     await handle_trade_update(data)
-                else:
-                    if not await handle_data_queue_msg(
-                        data, trader, data_loader
-                    ):
-                        while not queue.empty():
-                            _ = queue.get()
-                        tlog("cleaned queue")
+                elif not await handle_data_queue_msg(
+                    data, trader, data_loader
+                ):
+                    while not queue.empty():
+                        _ = queue.get()
+                    tlog("cleaned queue")
 
             except Empty:
                 await asyncio.sleep(0)
@@ -911,7 +909,7 @@ async def create_strategies(
             spec = importlib.util.spec_from_file_location(
                 "module.name", strategy_details["filename"]
             )
-            custom_strategy_module = importlib.util.module_from_spec(spec)
+            custom_strategy_module = importlib.util.module_from_spec(spec)  # type: ignore
             spec.loader.exec_module(custom_strategy_module)  # type: ignore
             class_name = strategy_name
 
