@@ -5,10 +5,10 @@ import multiprocessing as mp
 import os
 import traceback
 from datetime import datetime, timedelta
-from typing import Dict, List
+from typing import Dict, List, Optional
 
 from pytz import timezone
-from pytz.tzinfo import DstTzInfo
+from pytz.tzinfo import DstTzInfo  # type: ignore
 
 from liualgotrader.common import config
 from liualgotrader.common.data_loader import DataLoader  # type: ignore
@@ -42,18 +42,11 @@ async def scanner_runner(scanner: Scanner, queue: mp.Queue) -> None:
                     )
                 )
 
-            if scanner.recurrence:
-                try:
-                    await asyncio.sleep(scanner.recurrence.total_seconds())
-                    tlog(f"scanner {scanner.name} re-running")
-                except asyncio.CancelledError:
-                    tlog(
-                        f"scanner_runner({scanner.name}) cancelled during sleep, closing scanner task"
-                    )
-                    break
-            else:
+            if not scanner.recurrence:
                 break
 
+            await asyncio.sleep(scanner.recurrence.total_seconds())
+            tlog(f"scanner {scanner.name} re-running")
     except asyncio.CancelledError:
         tlog(
             f"scanner_runner() cancelled, closing scanner task {scanner.name}"
@@ -83,7 +76,7 @@ async def create_momentum_scanner(
             max_share_price=scanner_details["max_share_price"],
             min_volume=scanner_details["min_volume"],
             from_market_open=scanner_details["from_market_open"],
-            today_change_percent=scanner_details["min_gap"],
+            today_change_percent=scanner_details["today_change_percent"],
             recurrence=timedelta(minutes=recurrence) if recurrence else None,
             target_strategy_name=target_strategy_name,
             max_symbols=scanner_details.get(
@@ -164,10 +157,11 @@ async def scanners_runner(
 
 
 async def teardown_task(
-    to_market_close: timedelta, tasks: List[asyncio.Task]
+    to_market_close: Optional[timedelta], tasks: List[asyncio.Task]
 ) -> None:
     tlog("scanners_runner.teardown_task() starting")
-    if not config.market_close:
+
+    if not to_market_close or not config.market_close:
         tlog(
             "we're probably in market schedule by-pass mode, exiting teardown_task()"
         )
